//----------------------------------------------------------------------------
//	JIGFUNK.C
//
//	This module provides all the necessary functions for to control the test
//	jig's onboard hardware. 
//----------------------------------------------------------------------------

// INCLUDES 
#include <m8c.h>        // part specific constants and macros
#include "PSoCAPI.h"    // PSoC API definitions for all User Modules
#include "ctype.h"
#include "UART_1.h"
#include "AMUX8_1.h"
//#include "ADCINCVR_1.h"
#include "PGA_1.h"
#include "SAR6_1.h"
#include "TIMER8_1.h"
#include "stdlib.h"
#include "string.h"
#include <stdio.h>
#include "JIGFunk.h"




char * JIGFunk_getSineVoltage(int signalSelect, int sampleSelect){
//This function, called from main.c, selects which port to read data. 
//Then sets the sampling type: continous or average, and Max or Min Voltage.
//Converts the float to Char and returns.
	static char voltage[10];
	float voltageSamples[5];
	float  avgVoltage=0;
	int status;
	BYTE port=0;
	BYTE sampleType=0;
	int i=0;
	if (signalSelect==LED){
		port=AMUX8_1_PORT0_1;
		if (sampleSelect==HIGH)
			sampleType=continuousSamplingHigh;
		else 
			sampleType=continuousSamplingLow;
	}
	else if (signalSelect==BPF){
		port=AMUX8_1_PORT0_4;
		if (sampleSelect==HIGH)
			sampleType=continuousSamplingHigh;
		else 
			sampleType=continuousSamplingLow;
	}
	
		//for(i=0;i<5;i++){	
			voltageSamples[0]=JIGFunk_measureVoltage(port,sampleType);
		//	avgVoltage+=voltageSamples[i];
			//voltageSamples[i]=0;
		//}
	//avgVoltage/=5;
	//avgVoltage*=SCALE_FACTOR;
	
	strcpy(voltage,ftoa(voltageSamples[0],&status));
	voltageSamples[0]=0;
	//strcpy(voltage,ftoa(avgVoltage,&status));
	return voltage;
}
float JIGFunk_measureVoltage(BYTE channel, BYTE samplingType){	
// Based on the input parameters, the gathered voltage is averaged
// or Max/Min is found. The first dataset is thrown out, then the next
// 20 datasets are stored in ADCcount Array.

	static WORD  ADCcount[30];
	int loopCount = 0;
	float avgSample = 0;
	int i=0;
	WORD  temp=0;
	float  sampleMax=0;
	float  sampleMin=0;
	WORD tempSample=0;
	AMUX8_1_InputSelect(channel);
	JIGFunk_delay(15); 	
	//ADCINC14_1_Start(ADCINC14_1_HIGHPOWER);
	// first sample is thrown out
	
	SAR6_1_Start(SAR6_1_HIGHPOWER);
	/*
	while(1){
		SAR
		if(ADCINCVR_1_fIsDataAvailable()){				// check flag to see if last conversion is complete
			ADCcount[0] = ADCINCVR_1_iGetDataClearFlag();	// read sample from the ADC	
			break;
		}
	}
	*/
	ADCcount[0] = 0;
	loopCount=0;
	while (loopCount<30){
		//if(ADCINCVR_1_fIsDataAvailable()){
			//PRT0DR|=IO_TEST;	//Used to watch when this routine is entered via oscope
			ADCcount[loopCount]=(WORD)SAR6_1_cGetSample();
			//ADCcount[loopCount]=ADCINCVR_1_iGetDataClearFlag();
			loopCount++;
			//PRT0DR &= ~IO_TEST;//Used to watch when this routine is finished via oscope
			
		//}
	}
	SAR6_1_Stop();
	i=2;
	//Average sampling for DC voltages
	if (samplingType==averageSampling){
		for (i=0;i<20;i++){
			avgSample =avgSample+(ADCcount[i]*SCALE_FACTOR_7bit);
			ADCcount[i]=0;
		}
		return avgSample/20; 
	}
	
	//Finding peak voltage
	else if (samplingType==continuousSamplingHigh){
		if (ADCcount[i]>256)
			sampleMax=0;
		else 
			sampleMax=ADCcount[i];
		
			for (i = 2; i <30; i++){
				temp=ADCcount[i];
				if (temp>256)
					ADCcount[i]=0;
				else if ((ADCcount[i] > sampleMax)){
				sampleMax = ADCcount[i];
				}
				ADCcount[i]=0;
			}
			//Scaling based on resolution
			sampleMax*=SCALE_FACTOR_6bit;
			temp=0;
			return sampleMax;
	}
	//Finding min voltage
	else if (samplingType==continuousSamplingLow){
			sampleMin = ADCcount[i];
			for (i = 0; i <12; i++){
				if (ADCcount[i] < sampleMin){
					sampleMin = ADCcount[i];			
				}
				ADCcount[i]=0;
			}
			//Scaling based on resolution
			sampleMin*=SCALE_FACTOR_13bit;
			return sampleMin;
	}
	
	
	return;
}


// PUBLIC FUNCTIONS
void JIGFunk_delay(int milliseconds){
// creates a 1.28mS delay
// must first call initializeTimer()
//

	Timer8_1_Start();
	
	while(milliseconds){
		if(Timer8_1_bReadTimer() == 0x00)
			milliseconds --;
	}
}

void JIGFunk_initializeUART(void){
//	initialize UART
//	Modifies: Nothing
//	Effects: clear the command buffer, set UART for no
//				parity, and enables RX interrupts

	UART_1_CmdReset(); 								// reset command buffer to continue normal UART RX operation
	UART_1_Start(UART_PARITY_NONE);	
	UART_1_EnableInt();
	
}

void JIGFunk_sendSerialData(char *data){
//	serial data output
//	Modifies: UART TX buffer
//	Effects: transmit serial data, port assignment is tied to hardware settings
//				must first call initializeUART()

	UART_1_PutString(data);
}

void JIGFunk_initializeADC(void){
// Starting ADC,running continuously 
	//ADCINCVR_1_Start(ADCINCVR_1_HIGHPOWER);
	//ADCINCVR_1_GetSamples(0);
}

int JIGFunk_readSerialPort(char * rxData){
//	read the serial RX buffer
//	Modifies: Nothing
//	Effects: reads the RX buffer, looking for a 'CR' command delimiter
//				once found the command is then parsed from the serial data
//				must first call initializeUART()
//	Returns: 1 if unsuccessful
//			 0 if successful

	char *strPtr;
	BYTE error;	
	int i = 0; 
	while(1){
	
		if(UART_1_bCmdCheck()){					// look for 'CR' delimiter
			if(error = UART_1_bErrCheck())		// check for command errors
				return 1;
			if (strPtr = UART_1_szGetParam()){	// recover the actual command sent
				for (i=0;i<strlen(strPtr);i++){
					rxData[i]=toupper(strPtr[i]);
				}
				rxData[i]='\0';
				
				//strcpy(rxData,strPtr);			// copy to rxData and return value to caling function
				
				return 0;
			}	
			else
				return 1;
		}
	}
	return 1;
}

void JIGFunk_clearRXBuffer(void){
//	clears thew serial RX command buffer

	UART_1_CmdReset();     //Clear buffer, reset command buffer
}
		
void JIGFunk_changeGain(BYTE gain){
//	change the gain to the PGA
//	Modifies: the gain register
//	Effects: gain on the PGA 
//	Returns: Nothing
//	Refer to PGA datasheet for allowed gains
	PGA_1_Stop();
	PGA_1_SetGain(gain);
	PGA_1_Start(PGA_1_HIGHPOWER);
}

void JIGFunk_initializePGA(void){
	
	PGA_1_Start(PGA_1_HIGHPOWER);	
}

void JIGFunk_clearUARTCmd(void){
	UART_1_CmdReset();
}


char * JIGFunk_getVoltage(void){
//Function for finding DC voltage on P0[0]
	float voltage;
	int status;
	static char strVoltageSample[6];
	voltage = JIGFunk_measureVoltage(AMUX8_1_PORT0_0,averageSampling)*4 ;
	strncpy(strVoltageSample,ftoa(voltage,&status),5);
	strVoltageSample[6] = 0;	
	return strVoltageSample;
}

void JIGFunk_initializeTIMER(void){
	
	Timer8_1_WritePeriod(0X26);
	Timer8_1_EnableInt();
	Timer8_1_Start();
	
}

	