//----------------------------------------------------------------------------
//	POWER12V.C
//
//	Module includes functions to control the DUT input voltage
//		and to select the current sense resistor type
//
//----------------------------------------------------------------------------
//
// INCLUDES
#include <m8c.h>        // part specific constants and macros
#include "JIGFunk.h"
#include "Power12V.h"

//	PUBLIC FUNCTIONS
int Power12V_enable(void)
//	enables the DUT power
//	Modifies: port 1 line 2
//	Effects: enable switch for 12volt DUT power
//			 DUT voltage is read back to confirm its 12V +-5%
//	Returns: 1 if successful
//			 0 if voltage is not within spec
{
	PRT1DR |= CURRENT_SELECT; // set high current mode
	PRT1DR |= DUT_POWER_CTRL;
	
	return 1;
}

int Power12V_disable(void)
//	enables the DUT power
//	Modifies: port 1 line 2
//	Effects: enable switch for 12volt DUT power
//			 DUT voltage is read back to confirm its 12V +-5%
//	Returns: 1 if successful
//			 0 if voltage is not within spec
{
	PRT1DR &= ~DUT_POWER_CTRL;
	return 1;
}

//	PUBLIC FUNCTIONS
int Power12V_reset(void)
//	enables the DUT power
//	Modifies: port 1 line 2
//	Effects: enable switch for 12volt DUT power
//			 DUT voltage is read back to confirm its 12V +-5%
//	Returns: 1 if successful
//			 0 if voltage is not within spec
{
	PRT1DR |= CURRENT_SELECT; // set high current mode
	PRT1DR |= DUT_POWER_CTRL;
	//JIGFunk_delay(10);
	PRT1DR &= ~DUT_POWER_CTRL;
	return 1;
}


void Power12V_enableLowCurrentMode(void)
//	selects the 1k current sense resistor
//	Modifies: port 1 line 4
//	Effects: enable 1K current select resistor
//	Returns: nothing
{
	PRT1DR &= ~CURRENT_SELECT;	
}
	
void Power12V_enableHighCurrentMode(void)
//	selects the 1 ohm current sense resistor
//	Modifies: port 1 line 4
//	Effects: enable 1 ohm current select resistor
//	Returns: nothing
{
	PRT1DR |= CURRENT_SELECT;
}

