//----------------------------------------------------------------------------
//	POWER12V.H
//
//	Module includes functions to control the DUT input voltage
//		and to select the current sense resistor type
//
//----------------------------------------------------------------------------
//
// PREVENTS THIS HEADER FROM BEING LOADED MULTIPLE TIMES
#ifndef POWER12V_H
#define POWER12V_H
//
//	LOCAL DEFINES
#define DUT_POWER_CTRL				0x20	//port 1 line 5
#define CURRENT_SELECT				0x80	//port 1 line 7
//
//	PUBLIC FUNTIONS	
int Power12V_enable(void);
//
//	enables the DUT power
//	Modifies: port 1 line 2
//	Effects: enable switch for 12volt DUT power
//			 DUT voltage is read back to confirm its 12V +-5%
//	Returns: 1 if successful
//	
int Power12V_disable(void);
//
//	enables the DUT power
//	Modifies: port 1 line 2
//	Effects: enable switch for 12volt DUT power
//			 DUT voltage is read back to confirm its 12V +-5%
//	Returns: 1 if successful
//			 0 if voltage is not within spec

void Power12V_enableLowCurrentMode(void);
//
//	selects the 1k current sense resistor
//	Modifies: port 1 line 4
//	Effects: enable 1K current select resistor
//	Returns: nothing
//
void Power12V_enableHighCurrentMode(void);
//
//	selects the 1 ohm current sense resistor
//	Modifies: port 1 line 4
//	Effects: enable 1 ohm current select resistor
//	Returns: nothing

int Power12V_reset(void);
//
#endif