//----------------------------------------------------------------------------
//	JIGFUNK.H
//
//	This module provides all the necessary functions for to control the test
//	jig's onboard hardware. 

//
//----------------------------------------------------------------------------
#ifndef JIGFUNK_H
#define JIGFUNK_H
//
// LOCAL DEFINES 
#define MIN_CLK_COUNT				3000
#define ADC_SCALE 					16383
#define SCALE_FACTOR_14bit			0.00030517578125
#define SCALE_FACTOR_13bit			0.00061035156
#define SCALE_FACTOR_8bit			0.01953125
#define SCALE_FACTOR_7bit			0.0390625
#define SCALE_FACTOR_6bit			0.078125

#define ADC_RANGE 					5.0
#define HIGH 						1
#define LOW							0
#define LED							1
#define BPF							0
#define SAMPLE_SET					20
#define IO_TEST						0x01	//PORT 2 LINE 0
#define averageSampling				0
#define continuousSamplingHigh		1
#define continuousSamplingLow		2





//
// PUBLIC FUNCTIONS 
void JIGFunk_delay(int milliseconds);
//
// creates a 1.28mS delay
// must first call initializeTimer()
//
//
void JIGFunk_initializeUART(void);
//
//	initialize UART
//	Modifies: Nothing
//	Effects: clear the command buffer, set UART for no
//				parity, and enables RX interrupts
//
void JIGFunk_sendSerialData(char *data);
//
//	serial data output
//	Modifies: UART TX buffer
//	Effects: transmit serial data, port assignment is tied to hardware settings
//				must first call initializeUART()
//
void JIGFunk_initializeADC(void);
//
//	used to inistialize the two ADC in the psoc
//	ADCINC is used to measure the DUT's operating current
//	SAR6 is used to measure the voltage applied to the DUT
//	set both ADC's to continuous sample mode and high power


int JIGFunk_readSerialPort(char * rxData);
//
//	read the serial RX buffer
//	Modifies: Nothing
//	Effects: reads the RX buffer, looking for a 'CR' command delimiter
//				once found the command is then parsed from the serial data
//				must first call initializeUART()
//	Returns: 1 if unsuccessful
//			 0 if successful
//
void JIGFunk_clearRXBuffer(void);
//
//	clears thew serial RX command buffer
//
void JIGFunk_changeGain(BYTE gain);
//
//	change the gain to the PGA
//	Modifies: the gain register
//	Effects: gain on the PGA 
//	Returns: Nothing
//	Refer to PGA datasheet for allowed gains
//	
void JIGFunk_initializePGA(void);
//


char * JIGFunk_getDUTVoltage(void);
//

float JIGFunk_measureVoltage(BYTE channel, BYTE samplingType);	
//
// return an ADC count as INT
// count represents the analog voltage samples on the line
//

void JIGFunk_initializeTIMER(void);
void JIGFunk_clearUARTCmd(void);
void JIGFunk_displayHelpMenu(void);
char * JIGFunk_getSineVoltage(int signalSelect, int sampleSelect);


#endif